# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.position_mode import PositionMode
import pprint
import six


class CustomTag(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 position_mode=None,
                 keyframe_id=None,
                 time=None,
                 segment=None,
                 data=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, PositionMode, string_types, float, int, string_types) -> None
        super(CustomTag, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._position_mode = None
        self._keyframe_id = None
        self._time = None
        self._segment = None
        self._data = None
        self.discriminator = None

        if position_mode is not None:
            self.position_mode = position_mode
        if keyframe_id is not None:
            self.keyframe_id = keyframe_id
        if time is not None:
            self.time = time
        if segment is not None:
            self.segment = segment
        if data is not None:
            self.data = data

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(CustomTag, self), 'openapi_types'):
            types = getattr(super(CustomTag, self), 'openapi_types')

        types.update({
            'position_mode': 'PositionMode',
            'keyframe_id': 'string_types',
            'time': 'float',
            'segment': 'int',
            'data': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(CustomTag, self), 'attribute_map'):
            attributes = getattr(super(CustomTag, self), 'attribute_map')

        attributes.update({
            'position_mode': 'positionMode',
            'keyframe_id': 'keyframeId',
            'time': 'time',
            'segment': 'segment',
            'data': 'data'
        })
        return attributes

    @property
    def position_mode(self):
        # type: () -> PositionMode
        """Gets the position_mode of this CustomTag.

        The positioning mode that should be used when inserting the placement opportunity (required)

        :return: The position_mode of this CustomTag.
        :rtype: PositionMode
        """
        return self._position_mode

    @position_mode.setter
    def position_mode(self, position_mode):
        # type: (PositionMode) -> None
        """Sets the position_mode of this CustomTag.

        The positioning mode that should be used when inserting the placement opportunity (required)

        :param position_mode: The position_mode of this CustomTag.
        :type: PositionMode
        """

        if position_mode is not None:
            if not isinstance(position_mode, PositionMode):
                raise TypeError("Invalid type for `position_mode`, type has to be `PositionMode`")

        self._position_mode = position_mode

    @property
    def keyframe_id(self):
        # type: () -> string_types
        """Gets the keyframe_id of this CustomTag.

        Id of keyframe where the custom tag should be inserted. Required, when KEYFRAME is selected as position mode.

        :return: The keyframe_id of this CustomTag.
        :rtype: string_types
        """
        return self._keyframe_id

    @keyframe_id.setter
    def keyframe_id(self, keyframe_id):
        # type: (string_types) -> None
        """Sets the keyframe_id of this CustomTag.

        Id of keyframe where the custom tag should be inserted. Required, when KEYFRAME is selected as position mode.

        :param keyframe_id: The keyframe_id of this CustomTag.
        :type: string_types
        """

        if keyframe_id is not None:
            if not isinstance(keyframe_id, string_types):
                raise TypeError("Invalid type for `keyframe_id`, type has to be `string_types`")

        self._keyframe_id = keyframe_id

    @property
    def time(self):
        # type: () -> float
        """Gets the time of this CustomTag.

        Time in seconds where the custom tag should be inserted. Required, when TIME is selected as position mode.

        :return: The time of this CustomTag.
        :rtype: float
        """
        return self._time

    @time.setter
    def time(self, time):
        # type: (float) -> None
        """Sets the time of this CustomTag.

        Time in seconds where the custom tag should be inserted. Required, when TIME is selected as position mode.

        :param time: The time of this CustomTag.
        :type: float
        """

        if time is not None:
            if not isinstance(time, (float, int)):
                raise TypeError("Invalid type for `time`, type has to be `float`")

        self._time = time

    @property
    def segment(self):
        # type: () -> int
        """Gets the segment of this CustomTag.

        The custom tag will be inserted before the specified segment. Required, when SEGMENT is selected as position mode.

        :return: The segment of this CustomTag.
        :rtype: int
        """
        return self._segment

    @segment.setter
    def segment(self, segment):
        # type: (int) -> None
        """Sets the segment of this CustomTag.

        The custom tag will be inserted before the specified segment. Required, when SEGMENT is selected as position mode.

        :param segment: The segment of this CustomTag.
        :type: int
        """

        if segment is not None:
            if not isinstance(segment, int):
                raise TypeError("Invalid type for `segment`, type has to be `int`")

        self._segment = segment

    @property
    def data(self):
        # type: () -> string_types
        """Gets the data of this CustomTag.

        The data to be contained in the custom tag. (required)

        :return: The data of this CustomTag.
        :rtype: string_types
        """
        return self._data

    @data.setter
    def data(self, data):
        # type: (string_types) -> None
        """Sets the data of this CustomTag.

        The data to be contained in the custom tag. (required)

        :param data: The data of this CustomTag.
        :type: string_types
        """

        if data is not None:
            if not isinstance(data, string_types):
                raise TypeError("Invalid type for `data`, type has to be `string_types`")

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(CustomTag, self), "to_dict"):
            result = super(CustomTag, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomTag):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class SimpleEncodingLiveMaxResolution(Enum):
    FULL_HD = "FULL_HD"
    HD = "HD"
    SD = "SD"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class MuxingInformationVideoTrack(object):
    @poscheck_model
    def __init__(self,
                 index=None,
                 codec=None,
                 codec_iso=None,
                 bit_rate=None,
                 rate=None,
                 pixel_format=None,
                 frame_mode=None,
                 frame_width=None,
                 frame_height=None,
                 frame_rate=None,
                 start_time=None,
                 duration=None,
                 number_of_frames=None,
                 aspect_ratio=None):
        # type: (int, string_types, string_types, int, int, string_types, string_types, int, int, string_types, float, float, int, string_types) -> None

        self._index = None
        self._codec = None
        self._codec_iso = None
        self._bit_rate = None
        self._rate = None
        self._pixel_format = None
        self._frame_mode = None
        self._frame_width = None
        self._frame_height = None
        self._frame_rate = None
        self._start_time = None
        self._duration = None
        self._number_of_frames = None
        self._aspect_ratio = None
        self.discriminator = None

        if index is not None:
            self.index = index
        if codec is not None:
            self.codec = codec
        if codec_iso is not None:
            self.codec_iso = codec_iso
        if bit_rate is not None:
            self.bit_rate = bit_rate
        if rate is not None:
            self.rate = rate
        if pixel_format is not None:
            self.pixel_format = pixel_format
        if frame_mode is not None:
            self.frame_mode = frame_mode
        if frame_width is not None:
            self.frame_width = frame_width
        if frame_height is not None:
            self.frame_height = frame_height
        if frame_rate is not None:
            self.frame_rate = frame_rate
        if start_time is not None:
            self.start_time = start_time
        if duration is not None:
            self.duration = duration
        if number_of_frames is not None:
            self.number_of_frames = number_of_frames
        if aspect_ratio is not None:
            self.aspect_ratio = aspect_ratio

    @property
    def openapi_types(self):
        types = {
            'index': 'int',
            'codec': 'string_types',
            'codec_iso': 'string_types',
            'bit_rate': 'int',
            'rate': 'int',
            'pixel_format': 'string_types',
            'frame_mode': 'string_types',
            'frame_width': 'int',
            'frame_height': 'int',
            'frame_rate': 'string_types',
            'start_time': 'float',
            'duration': 'float',
            'number_of_frames': 'int',
            'aspect_ratio': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'index': 'index',
            'codec': 'codec',
            'codec_iso': 'codecIso',
            'bit_rate': 'bitRate',
            'rate': 'rate',
            'pixel_format': 'pixelFormat',
            'frame_mode': 'frameMode',
            'frame_width': 'frameWidth',
            'frame_height': 'frameHeight',
            'frame_rate': 'frameRate',
            'start_time': 'startTime',
            'duration': 'duration',
            'number_of_frames': 'numberOfFrames',
            'aspect_ratio': 'aspectRatio'
        }
        return attributes

    @property
    def index(self):
        # type: () -> int
        """Gets the index of this MuxingInformationVideoTrack.

        The stream index in the container

        :return: The index of this MuxingInformationVideoTrack.
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        # type: (int) -> None
        """Sets the index of this MuxingInformationVideoTrack.

        The stream index in the container

        :param index: The index of this MuxingInformationVideoTrack.
        :type: int
        """

        if index is not None:
            if not isinstance(index, int):
                raise TypeError("Invalid type for `index`, type has to be `int`")

        self._index = index

    @property
    def codec(self):
        # type: () -> string_types
        """Gets the codec of this MuxingInformationVideoTrack.

        The codec used for the track

        :return: The codec of this MuxingInformationVideoTrack.
        :rtype: string_types
        """
        return self._codec

    @codec.setter
    def codec(self, codec):
        # type: (string_types) -> None
        """Sets the codec of this MuxingInformationVideoTrack.

        The codec used for the track

        :param codec: The codec of this MuxingInformationVideoTrack.
        :type: string_types
        """

        if codec is not None:
            if not isinstance(codec, string_types):
                raise TypeError("Invalid type for `codec`, type has to be `string_types`")

        self._codec = codec

    @property
    def codec_iso(self):
        # type: () -> string_types
        """Gets the codec_iso of this MuxingInformationVideoTrack.

        The codec string of the track

        :return: The codec_iso of this MuxingInformationVideoTrack.
        :rtype: string_types
        """
        return self._codec_iso

    @codec_iso.setter
    def codec_iso(self, codec_iso):
        # type: (string_types) -> None
        """Sets the codec_iso of this MuxingInformationVideoTrack.

        The codec string of the track

        :param codec_iso: The codec_iso of this MuxingInformationVideoTrack.
        :type: string_types
        """

        if codec_iso is not None:
            if not isinstance(codec_iso, string_types):
                raise TypeError("Invalid type for `codec_iso`, type has to be `string_types`")

        self._codec_iso = codec_iso

    @property
    def bit_rate(self):
        # type: () -> int
        """Gets the bit_rate of this MuxingInformationVideoTrack.

        The bitrate of the video track

        :return: The bit_rate of this MuxingInformationVideoTrack.
        :rtype: int
        """
        return self._bit_rate

    @bit_rate.setter
    def bit_rate(self, bit_rate):
        # type: (int) -> None
        """Sets the bit_rate of this MuxingInformationVideoTrack.

        The bitrate of the video track

        :param bit_rate: The bit_rate of this MuxingInformationVideoTrack.
        :type: int
        """

        if bit_rate is not None:
            if not isinstance(bit_rate, int):
                raise TypeError("Invalid type for `bit_rate`, type has to be `int`")

        self._bit_rate = bit_rate

    @property
    def rate(self):
        # type: () -> int
        """Gets the rate of this MuxingInformationVideoTrack.


        :return: The rate of this MuxingInformationVideoTrack.
        :rtype: int
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        # type: (int) -> None
        """Sets the rate of this MuxingInformationVideoTrack.


        :param rate: The rate of this MuxingInformationVideoTrack.
        :type: int
        """

        if rate is not None:
            if not isinstance(rate, int):
                raise TypeError("Invalid type for `rate`, type has to be `int`")

        self._rate = rate

    @property
    def pixel_format(self):
        # type: () -> string_types
        """Gets the pixel_format of this MuxingInformationVideoTrack.

        The pixel format used

        :return: The pixel_format of this MuxingInformationVideoTrack.
        :rtype: string_types
        """
        return self._pixel_format

    @pixel_format.setter
    def pixel_format(self, pixel_format):
        # type: (string_types) -> None
        """Sets the pixel_format of this MuxingInformationVideoTrack.

        The pixel format used

        :param pixel_format: The pixel_format of this MuxingInformationVideoTrack.
        :type: string_types
        """

        if pixel_format is not None:
            if not isinstance(pixel_format, string_types):
                raise TypeError("Invalid type for `pixel_format`, type has to be `string_types`")

        self._pixel_format = pixel_format

    @property
    def frame_mode(self):
        # type: () -> string_types
        """Gets the frame_mode of this MuxingInformationVideoTrack.

        The frame mode (e.g. progressive)

        :return: The frame_mode of this MuxingInformationVideoTrack.
        :rtype: string_types
        """
        return self._frame_mode

    @frame_mode.setter
    def frame_mode(self, frame_mode):
        # type: (string_types) -> None
        """Sets the frame_mode of this MuxingInformationVideoTrack.

        The frame mode (e.g. progressive)

        :param frame_mode: The frame_mode of this MuxingInformationVideoTrack.
        :type: string_types
        """

        if frame_mode is not None:
            if not isinstance(frame_mode, string_types):
                raise TypeError("Invalid type for `frame_mode`, type has to be `string_types`")

        self._frame_mode = frame_mode

    @property
    def frame_width(self):
        # type: () -> int
        """Gets the frame_width of this MuxingInformationVideoTrack.

        The width of the frame in pixel

        :return: The frame_width of this MuxingInformationVideoTrack.
        :rtype: int
        """
        return self._frame_width

    @frame_width.setter
    def frame_width(self, frame_width):
        # type: (int) -> None
        """Sets the frame_width of this MuxingInformationVideoTrack.

        The width of the frame in pixel

        :param frame_width: The frame_width of this MuxingInformationVideoTrack.
        :type: int
        """

        if frame_width is not None:
            if not isinstance(frame_width, int):
                raise TypeError("Invalid type for `frame_width`, type has to be `int`")

        self._frame_width = frame_width

    @property
    def frame_height(self):
        # type: () -> int
        """Gets the frame_height of this MuxingInformationVideoTrack.

        The height of the frame in pixel

        :return: The frame_height of this MuxingInformationVideoTrack.
        :rtype: int
        """
        return self._frame_height

    @frame_height.setter
    def frame_height(self, frame_height):
        # type: (int) -> None
        """Sets the frame_height of this MuxingInformationVideoTrack.

        The height of the frame in pixel

        :param frame_height: The frame_height of this MuxingInformationVideoTrack.
        :type: int
        """

        if frame_height is not None:
            if not isinstance(frame_height, int):
                raise TypeError("Invalid type for `frame_height`, type has to be `int`")

        self._frame_height = frame_height

    @property
    def frame_rate(self):
        # type: () -> string_types
        """Gets the frame_rate of this MuxingInformationVideoTrack.

        The frame rate of the stream in fractional format

        :return: The frame_rate of this MuxingInformationVideoTrack.
        :rtype: string_types
        """
        return self._frame_rate

    @frame_rate.setter
    def frame_rate(self, frame_rate):
        # type: (string_types) -> None
        """Sets the frame_rate of this MuxingInformationVideoTrack.

        The frame rate of the stream in fractional format

        :param frame_rate: The frame_rate of this MuxingInformationVideoTrack.
        :type: string_types
        """

        if frame_rate is not None:
            if not isinstance(frame_rate, string_types):
                raise TypeError("Invalid type for `frame_rate`, type has to be `string_types`")

        self._frame_rate = frame_rate

    @property
    def start_time(self):
        # type: () -> float
        """Gets the start_time of this MuxingInformationVideoTrack.

        The start time in seconds

        :return: The start_time of this MuxingInformationVideoTrack.
        :rtype: float
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        # type: (float) -> None
        """Sets the start_time of this MuxingInformationVideoTrack.

        The start time in seconds

        :param start_time: The start_time of this MuxingInformationVideoTrack.
        :type: float
        """

        if start_time is not None:
            if not isinstance(start_time, (float, int)):
                raise TypeError("Invalid type for `start_time`, type has to be `float`")

        self._start_time = start_time

    @property
    def duration(self):
        # type: () -> float
        """Gets the duration of this MuxingInformationVideoTrack.

        The duration in seconds

        :return: The duration of this MuxingInformationVideoTrack.
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        # type: (float) -> None
        """Sets the duration of this MuxingInformationVideoTrack.

        The duration in seconds

        :param duration: The duration of this MuxingInformationVideoTrack.
        :type: float
        """

        if duration is not None:
            if not isinstance(duration, (float, int)):
                raise TypeError("Invalid type for `duration`, type has to be `float`")

        self._duration = duration

    @property
    def number_of_frames(self):
        # type: () -> int
        """Gets the number_of_frames of this MuxingInformationVideoTrack.

        The number of frames of that video track

        :return: The number_of_frames of this MuxingInformationVideoTrack.
        :rtype: int
        """
        return self._number_of_frames

    @number_of_frames.setter
    def number_of_frames(self, number_of_frames):
        # type: (int) -> None
        """Sets the number_of_frames of this MuxingInformationVideoTrack.

        The number of frames of that video track

        :param number_of_frames: The number_of_frames of this MuxingInformationVideoTrack.
        :type: int
        """

        if number_of_frames is not None:
            if not isinstance(number_of_frames, int):
                raise TypeError("Invalid type for `number_of_frames`, type has to be `int`")

        self._number_of_frames = number_of_frames

    @property
    def aspect_ratio(self):
        # type: () -> string_types
        """Gets the aspect_ratio of this MuxingInformationVideoTrack.

        The aspect ratio of the stream

        :return: The aspect_ratio of this MuxingInformationVideoTrack.
        :rtype: string_types
        """
        return self._aspect_ratio

    @aspect_ratio.setter
    def aspect_ratio(self, aspect_ratio):
        # type: (string_types) -> None
        """Sets the aspect_ratio of this MuxingInformationVideoTrack.

        The aspect ratio of the stream

        :param aspect_ratio: The aspect_ratio of this MuxingInformationVideoTrack.
        :type: string_types
        """

        if aspect_ratio is not None:
            if not isinstance(aspect_ratio, string_types):
                raise TypeError("Invalid type for `aspect_ratio`, type has to be `string_types`")

        self._aspect_ratio = aspect_ratio

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MuxingInformationVideoTrack):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.simple_encoding_vod_job_credentials import SimpleEncodingVodJobCredentials
from bitmovin_api_sdk.models.simple_encoding_vod_job_input import SimpleEncodingVodJobInput
from bitmovin_api_sdk.models.simple_encoding_vod_job_input_type import SimpleEncodingVodJobInputType
import pprint
import six


class SimpleEncodingVodJobUrlInput(SimpleEncodingVodJobInput):
    @poscheck_model
    def __init__(self,
                 url=None,
                 credentials=None,
                 input_type=None,
                 language=None):
        # type: (string_types, SimpleEncodingVodJobCredentials, SimpleEncodingVodJobInputType, string_types) -> None
        super(SimpleEncodingVodJobUrlInput, self).__init__()

        self._url = None
        self._credentials = None
        self._input_type = None
        self._language = None
        self.discriminator = None

        if url is not None:
            self.url = url
        if credentials is not None:
            self.credentials = credentials
        if input_type is not None:
            self.input_type = input_type
        if language is not None:
            self.language = language

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(SimpleEncodingVodJobUrlInput, self), 'openapi_types'):
            types = getattr(super(SimpleEncodingVodJobUrlInput, self), 'openapi_types')

        types.update({
            'url': 'string_types',
            'credentials': 'SimpleEncodingVodJobCredentials',
            'input_type': 'SimpleEncodingVodJobInputType',
            'language': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(SimpleEncodingVodJobUrlInput, self), 'attribute_map'):
            attributes = getattr(super(SimpleEncodingVodJobUrlInput, self), 'attribute_map')

        attributes.update({
            'url': 'url',
            'credentials': 'credentials',
            'input_type': 'inputType',
            'language': 'language'
        })
        return attributes

    @property
    def url(self):
        # type: () -> string_types
        """Gets the url of this SimpleEncodingVodJobUrlInput.

        Define a URL pointing to the asset that should be encoded. The URL has to point to a file.  Currently the following protocols/storages systems are supported: HTTP(S), (S)FTP, S3, GCS, Azure Blob Storage, Akamai NetStorage. Note that most protocols will require `credentials` to access the asset. Check the description below which ones are applicable. See below how to construct the URLs for the individual protocols/storage systems.  ---  **HTTP** and **HTTPS**: * `http://<host>[:<port>]/path/file.mp4` * `https://<host>[:<port>]/path/file.mp4`  The port is defaulted to 80 if it's not provided. If the content is secured by Basic Authentication please provide corresponding credentials.  **FTP** and **SFTP**: * `ftp://<host>[:<port>]/path/file.mp4` * `sftp://<host>[:<port>]/path/file.mp4`  The port is defaulted to 21 (ftp) or  22 (sftp) if it's not provided. If the content is secured please provide corresponding credentials.  **S3**: * `s3://<my-bucket>/path/file.mp4`  Authentication can be done via accesskey/secretkey or role-based authentication. Generic S3 is currently NOT supported.  **GCS**: * `gcs://<my-bucket>/path/file.mp4`  Authentication can be done via accesskey/secretkey or a service account  **Azure Blob Storage (ABS)**: * `https://<account>.blob.core.windows.net/<container>/path/file.mp4`  It is required to provide the Azure key credentials for authentication.  **Akamai NetStorage**: * `https://<host>-nsu.akamaihd.net/<CP-code>/path/file.mp4`  It is required to provide username/password credentials for authentication. (required)

        :return: The url of this SimpleEncodingVodJobUrlInput.
        :rtype: string_types
        """
        return self._url

    @url.setter
    def url(self, url):
        # type: (string_types) -> None
        """Sets the url of this SimpleEncodingVodJobUrlInput.

        Define a URL pointing to the asset that should be encoded. The URL has to point to a file.  Currently the following protocols/storages systems are supported: HTTP(S), (S)FTP, S3, GCS, Azure Blob Storage, Akamai NetStorage. Note that most protocols will require `credentials` to access the asset. Check the description below which ones are applicable. See below how to construct the URLs for the individual protocols/storage systems.  ---  **HTTP** and **HTTPS**: * `http://<host>[:<port>]/path/file.mp4` * `https://<host>[:<port>]/path/file.mp4`  The port is defaulted to 80 if it's not provided. If the content is secured by Basic Authentication please provide corresponding credentials.  **FTP** and **SFTP**: * `ftp://<host>[:<port>]/path/file.mp4` * `sftp://<host>[:<port>]/path/file.mp4`  The port is defaulted to 21 (ftp) or  22 (sftp) if it's not provided. If the content is secured please provide corresponding credentials.  **S3**: * `s3://<my-bucket>/path/file.mp4`  Authentication can be done via accesskey/secretkey or role-based authentication. Generic S3 is currently NOT supported.  **GCS**: * `gcs://<my-bucket>/path/file.mp4`  Authentication can be done via accesskey/secretkey or a service account  **Azure Blob Storage (ABS)**: * `https://<account>.blob.core.windows.net/<container>/path/file.mp4`  It is required to provide the Azure key credentials for authentication.  **Akamai NetStorage**: * `https://<host>-nsu.akamaihd.net/<CP-code>/path/file.mp4`  It is required to provide username/password credentials for authentication. (required)

        :param url: The url of this SimpleEncodingVodJobUrlInput.
        :type: string_types
        """

        if url is not None:
            if not isinstance(url, string_types):
                raise TypeError("Invalid type for `url`, type has to be `string_types`")

        self._url = url

    @property
    def credentials(self):
        # type: () -> SimpleEncodingVodJobCredentials
        """Gets the credentials of this SimpleEncodingVodJobUrlInput.

        Credentials to be used for authentication and accessing the file. Check out the examples on how to define the credentials correctly. 

        :return: The credentials of this SimpleEncodingVodJobUrlInput.
        :rtype: SimpleEncodingVodJobCredentials
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        # type: (SimpleEncodingVodJobCredentials) -> None
        """Sets the credentials of this SimpleEncodingVodJobUrlInput.

        Credentials to be used for authentication and accessing the file. Check out the examples on how to define the credentials correctly. 

        :param credentials: The credentials of this SimpleEncodingVodJobUrlInput.
        :type: SimpleEncodingVodJobCredentials
        """

        if credentials is not None:
            if not isinstance(credentials, SimpleEncodingVodJobCredentials):
                raise TypeError("Invalid type for `credentials`, type has to be `SimpleEncodingVodJobCredentials`")

        self._credentials = credentials

    @property
    def input_type(self):
        # type: () -> SimpleEncodingVodJobInputType
        """Gets the input_type of this SimpleEncodingVodJobUrlInput.

        Defines the type of the input file, if no type is set it is assumed that the input file contains at least one video stream and optionally one or multiple audio streams.  Note that when defining video and audio inputs, you can either - add one single input without inputType, in which case that source file must contain a video stream and (if you want audio) one audio stream, or - add one single input with inputType=VIDEO and (if you want audio) one or more inputs with inputType=AUDIO (each containing one audio stream)  Other combinations are not valid. 

        :return: The input_type of this SimpleEncodingVodJobUrlInput.
        :rtype: SimpleEncodingVodJobInputType
        """
        return self._input_type

    @input_type.setter
    def input_type(self, input_type):
        # type: (SimpleEncodingVodJobInputType) -> None
        """Sets the input_type of this SimpleEncodingVodJobUrlInput.

        Defines the type of the input file, if no type is set it is assumed that the input file contains at least one video stream and optionally one or multiple audio streams.  Note that when defining video and audio inputs, you can either - add one single input without inputType, in which case that source file must contain a video stream and (if you want audio) one audio stream, or - add one single input with inputType=VIDEO and (if you want audio) one or more inputs with inputType=AUDIO (each containing one audio stream)  Other combinations are not valid. 

        :param input_type: The input_type of this SimpleEncodingVodJobUrlInput.
        :type: SimpleEncodingVodJobInputType
        """

        if input_type is not None:
            if not isinstance(input_type, SimpleEncodingVodJobInputType):
                raise TypeError("Invalid type for `input_type`, type has to be `SimpleEncodingVodJobInputType`")

        self._input_type = input_type

    @property
    def language(self):
        # type: () -> string_types
        """Gets the language of this SimpleEncodingVodJobUrlInput.

        The language of the audio track, the subtitles, or closed captions file. The language code  must be compliant with [BCP 47](https://datatracker.ietf.org/doc/html/rfc5646).  This property is mandatory if the input provided is of type SUBTITLES or CLOSED_CAPTIONS and  recommended for input type AUDIO and an input that does not specify an input type (combined  audio and video). If an audio input does not specify the language, it is defaulted to `und`  (undefined). 

        :return: The language of this SimpleEncodingVodJobUrlInput.
        :rtype: string_types
        """
        return self._language

    @language.setter
    def language(self, language):
        # type: (string_types) -> None
        """Sets the language of this SimpleEncodingVodJobUrlInput.

        The language of the audio track, the subtitles, or closed captions file. The language code  must be compliant with [BCP 47](https://datatracker.ietf.org/doc/html/rfc5646).  This property is mandatory if the input provided is of type SUBTITLES or CLOSED_CAPTIONS and  recommended for input type AUDIO and an input that does not specify an input type (combined  audio and video). If an audio input does not specify the language, it is defaulted to `und`  (undefined). 

        :param language: The language of this SimpleEncodingVodJobUrlInput.
        :type: string_types
        """

        if language is not None:
            if not isinstance(language, string_types):
                raise TypeError("Invalid type for `language`, type has to be `string_types`")

        self._language = language

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(SimpleEncodingVodJobUrlInput, self), "to_dict"):
            result = super(SimpleEncodingVodJobUrlInput, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimpleEncodingVodJobUrlInput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class Vp9AqMode(Enum):
    NONE = "NONE"
    VARIANCE = "VARIANCE"
    COMPLEXITY = "COMPLEXITY"
    CYCLIC = "CYCLIC"
